@@ -298,8 +298,12 @@ class LoadMaster(HttpClient):
                                                                vs)
             else:
                 virt_serv = self.build_virtual_service(service_data, response)
+            for server_data in service_data.get("Rs", []):
+                rs = virt_serv.build_real_server(server_data)
+                virt_serv.real_servers.append(rs)
             virtual_services.append(virt_serv)
 
+        """
         rs_vs_indexes = [(rs['VSIndex'], rs)
                          for rs in global_real_servers_data]
         rs_vs_indexes = dict(rs_vs_indexes)
@@ -312,6 +316,7 @@ class LoadMaster(HttpClient):
                 if subvs.index in rs_vs_indexes:
                     rs = subvs.build_real_server(rs_vs_indexes[subvs.index])
                     subvs.real_servers.append(rs)
+        """
 
         return virtual_services
 
@@ -812,24 +817,6 @@ class VirtualService(HttpClient, KempBaseObjectModel):
         self.qos = service.get('QoS', None)
         self.idletime = service.get('Idletime', None)
 
-        # Real servers section
-        self.checktype = service.get('CheckType', None)
-        self.checkhost = service.get('CheckHost', None)
-        self.checkpattern = service.get('CheckPattern', None)
-        self.checkurl = service.get('CheckUrl', None)
-        self.checkcodes = service.get('CheckCodes', None)
-        self.checkheaders = service.get('CheckHeaders', None)
-        self.matchlen = service.get('MatchLen', None)
-        self.__dict__['checkuse1.1'] = service.get('CheckUse1.1', None)
-        self.checkport = falsey_to_none(int(service.get('CheckPort', 0)))
-        self.checkuseget = service.get('CheckUseGet', None)
-        self.extrahdrkey = service.get('ExtraHdrKey', None)
-        self.extrahdrvalue = service.get('ExtraHdrValue', None)
-        self.checkpostdata = service.get('CheckPostData', None)
-        self.rsruleprecedence = service.get('RSRulePrecedence', None)
-        self.rsruleprecedencepos = service.get('RSRulePrecedencePos', None)
-        self.enhancedhealthchecks = service.get('EnhancedHealthchecks', None)
-
     def create_sub_virtual_service(self):
         """VirtualService factory with pre-configured LoadMaster connection
 
